pub trait MeetingNotesProvider: Send + Sync {
// Required methods
fn provider_name(&self) -> &'static str;
fn get_meetings<'life0, 'async_trait>(
&'life0 self,
filter: MeetingFilter,
) -> Pin<Box<dyn Future<Output = Result<ProviderResult<MeetingNote>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait;
fn get_transcript<'life0, 'life1, 'async_trait>(
&'life0 self,
meeting_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<MeetingTranscript>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
fn search_meetings<'life0, 'life1, 'async_trait>(
&'life0 self,
query: &'life1 str,
filter: MeetingFilter,
) -> Pin<Box<dyn Future<Output = Result<ProviderResult<MeetingNote>>> + Send + 'async_trait>>
where Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait;
}Expand description
Provider for meeting notes and transcripts.
Implementations include Fireflies.ai.
Required Methods
Sourcefn provider_name(&self) -> &'static str
fn provider_name(&self) -> &'static str
Get the provider name for logging (e.g., “fireflies”).
Sourcefn get_meetings<'life0, 'async_trait>(
&'life0 self,
filter: MeetingFilter,
) -> Pin<Box<dyn Future<Output = Result<ProviderResult<MeetingNote>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
fn get_meetings<'life0, 'async_trait>(
&'life0 self,
filter: MeetingFilter,
) -> Pin<Box<dyn Future<Output = Result<ProviderResult<MeetingNote>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
Get a list of meeting notes with optional filters.
Sourcefn get_transcript<'life0, 'life1, 'async_trait>(
&'life0 self,
meeting_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<MeetingTranscript>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn get_transcript<'life0, 'life1, 'async_trait>(
&'life0 self,
meeting_id: &'life1 str,
) -> Pin<Box<dyn Future<Output = Result<MeetingTranscript>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Get the full transcript for a meeting.
Sourcefn search_meetings<'life0, 'life1, 'async_trait>(
&'life0 self,
query: &'life1 str,
filter: MeetingFilter,
) -> Pin<Box<dyn Future<Output = Result<ProviderResult<MeetingNote>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
fn search_meetings<'life0, 'life1, 'async_trait>(
&'life0 self,
query: &'life1 str,
filter: MeetingFilter,
) -> Pin<Box<dyn Future<Output = Result<ProviderResult<MeetingNote>>> + Send + 'async_trait>>where
Self: 'async_trait,
'life0: 'async_trait,
'life1: 'async_trait,
Search meetings by keyword across titles, action items, keywords, and topics.